@@ -7,34 +7,42 @@ from stock import constants
 
 class Stock(models.Model):
 
-    stock = models.IntegerField(_('Stock'), default=0)
+    stock = models.FloatField(_('Stock'), default=0)
 
-    min_stock = models.IntegerField(_('Minimum stock'), default=0)
+    min_stock = models.FloatField(_('Minimum stock'), default=0)
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.initial_stock = self.stock
 
     def add_stock(self, value):
 
-        self.validate_stock_value(value)
+        clean_value = self.clean_stock_value(value)
 
-        self.stock += value
+        self.stock += clean_value
         self._commit_stock()
 
     def subtract_stock(self, value):
 
-        self.validate_stock_value(value)
+        clean_value = self.clean_stock_value(value)
 
-        if self.stock < value:
+        if self.stock < clean_value:
             raise ValueError(_('Not enough stock items'))
 
-        self.stock -= value
+        self.stock -= clean_value
         self._commit_stock()
 
-    def validate_stock_value(self, value):
+    def clean_stock_value(self, value):
 
-        if not isinstance(value, int):
-            raise ValueError(_('Value should be integer'))
+        try:
+            value = float(value)
+        except Exception:
+            raise ValueError(_('Value should be float'))
 
-        if value < 1:
-            raise ValueError(_('Value less then 1'))
+        if value <= 0:
+            raise ValueError(_('Value less then 0.1'))
+
+        return value
 
     def _commit_stock(self):
         self.save(update_fields=['stock'])
